#
# spec file for package gdk-pixbuf
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# When updating the binary version, do not forget to also update baselibs.conf
%define gdk_pixbuf_binary_version 2.10.0

Name:           gdk-pixbuf
Version:        2.34.0
Release:        5.1
Summary:        An image loading library
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://www.gnome.org/
Source:         http://download.gnome.org/sources/gdk-pixbuf/2.34/%{name}-%{version}.tar.xz
Source1:        macros.gdk-pixbuf
Source2:        README.SUSE
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM gdk-pixbuf-bgo768688-bmp-overflow.patch bgo#768688 mgorse@suse.com -- fix a bmp overflow.
Patch0:         gdk-pixbuf-bgo768688-bmp-overflow.patch
# PATCh-FIX-UPSTREAM gdk-pixbuf-bgo768484-ico-set-errors.patch bgo#768484 mgorse@suse.com -- ico: always set errors.
Patch1:         gdk-pixbuf-bgo768484-ico-set-errors.patch
# PATCH-FIX-UPSTREAM gdk-pixbuf-bgo769738-bmp-overflow.patch bsc#988745 bgo#769738 mgorse@suse.com -- fix another bmp overflow.
Patch2:         gdk-pixbuf-bgo769738-bmp-overflow.patch
# PATCh-FIX-UPSTREAM gdk-pixbuf-bgo769170-ico-headers.patch bsc#991450 bgo#769170 CVE-2016-6352 mgorse@suse.com -- be more careful when parsing ico headers.
Patch3:         gdk-pixbuf-bgo769170-ico-headers.patch
Patch10:        u_contrib-gdk-pixbuf-xlib-Fix-rgb888amsb.patch
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(glib-2.0) >= 2.37.2
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)

%description
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package -n libgdk_pixbuf-2_0-0
Summary:        An image loading library
Group:          System/Libraries
# Provide %{name} to make the lang package installable
Provides:       %{name} = %{version}
Requires(post): gdk-pixbuf-query-loaders
Recommends:     %{name}-lang = %{version}
Conflicts:      gtk2 < 2.21.3

%description  -n libgdk_pixbuf-2_0-0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

%package -n typelib-1_0-GdkPixbuf-2_0
Summary:        An image loading library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GdkPixbuf-2_0
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package provides the GObject Introspection bindings for gdk-pixbuf.

%package query-loaders
Summary:        An image loading library - Utility to create loaders cache
Group:          System/Libraries

%description query-loaders
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains the utility to create the cache file needed for
loadable modules.

%package devel
Summary:        An image loading library - Development Files
Group:          Development/Languages/C and C++
Requires:       libgdk_pixbuf-2_0-0 = %{version}
Requires:       typelib-1_0-GdkPixbuf-2_0 = %{version}

%description devel
gdk-pixbuf is an image loading library that can be extended by loadable
modules for new image formats. It is used by toolkits such as GTK+ or
Clutter.

This package contains development files for gdk-pixbuf.

%lang_package
%prep
%setup -q
translation-update-upstream
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch10 -p1
%if "%_lib" == "lib64"
cp -a %{S:2} .
%endif

%build
%configure \
        --disable-static \
        --enable-introspection \
        --with-libjasper \
        --with-x11
%{__make} %{?_smp_mflags}

%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -delete -print
%find_lang %{name}
touch %{buildroot}%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache
%if "%_lib" == "lib64"
  mv %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders %{buildroot}%{_bindir}/gdk-pixbuf-query-loaders-64
  mv %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders.1 %{buildroot}%{_mandir}/man1/gdk-pixbuf-query-loaders-64.1
%endif
# Install rpm macros
mkdir -p %{buildroot}%{_sysconfdir}/rpm
cp %{S:1} %{buildroot}%{_sysconfdir}/rpm

###########################################################################
# Note: when updating scriptlets, don't forget to also update baselibs.conf
###########################################################################

# Convenient %define for the scriplets
%if "%_lib" == "lib64"
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders-64
%else
%define _gdk_pixbuf_query_loaders %{_bindir}/gdk-pixbuf-query-loaders
%endif
%define _gdk_pixbuf_query_loaders_update_cache %{_gdk_pixbuf_query_loaders} --update-cache

%post -n libgdk_pixbuf-2_0-0
/sbin/ldconfig
%if 0
# In case libgdk_pixbuf-2_0-0 gets installed before gdk-pixbuf-query-loaders,
# we don't want to fail. So we make the call to gdk-pixbuf-query-loaders
# dependent on the existence of the binary. This is why we also have a %post
# for gdk-pixbuf-query-loaders.
%endif
if test -f %{_gdk_pixbuf_query_loaders}; then
  %{_gdk_pixbuf_query_loaders_update_cache}
fi

%post query-loaders
%if 0
# If we install gdk-pixbuf-query-loaders for the first time, then we should run
# it in case libgdk_pixbuf-2_0-0 was installed first (ie, if
# %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version} already exists) which
# means gdk-pixbuf-query-loaders couldn't run there.
%endif
if [ $1 = 1 ]; then
  test -d %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
  if test $? -eq 0; then
    %{_gdk_pixbuf_query_loaders_update_cache}
  fi
fi

%if 0
# No need to call gdk-pixbuf-query-loaders in postun:
# - if it's an upgrade, it will have been called in post
# - if it's an uninstall, we don't care about this anymore
%endif

%postun -n libgdk_pixbuf-2_0-0 -p /sbin/ldconfig

%files -n libgdk_pixbuf-2_0-0
%defattr(-, root, root)
%doc AUTHORS COPYING NEWS
%if "%_lib" == "lib64"
%doc README.SUSE
%endif
%{_libdir}/libgdk_pixbuf-2.0.so.0*
%{_libdir}/libgdk_pixbuf_xlib-2.0.so.0*
%dir %{_libdir}/gdk-pixbuf-2.0
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}
%dir %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders
%{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders/*.so
%ghost %{_libdir}/gdk-pixbuf-2.0/%{gdk_pixbuf_binary_version}/loaders.cache

%files -n typelib-1_0-GdkPixbuf-2_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/GdkPixbuf-2.0.typelib

%files query-loaders
%defattr(-, root, root)
%{_bindir}/gdk-pixbuf-query-loaders*
%{_mandir}/man1/gdk-pixbuf-query-loaders*.1*

%files devel
%defattr(-, root, root)
%{_bindir}/gdk-pixbuf-csource
%{_bindir}/gdk-pixbuf-pixdata
%{_mandir}/man1/gdk-pixbuf-csource.1*
%{_includedir}/gdk-pixbuf-2.0
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_datadir}/gir-1.0/GdkPixbuf-2.0.gir
%doc %{_datadir}/gtk-doc/html/gdk-pixbuf
%{_sysconfdir}/rpm/macros.gdk-pixbuf

%files lang -f %{name}.lang

%changelog
* Mon Dec 12 2016 mstaudt@suse.com
- u_contrib-gdk-pixbuf-xlib-Fix-rgb888amsb.patch
  Fix RGBA conversion for big endian X11 environments.
  Fixes (boo#929462), (bsc#1010497)
* Tue Aug 30 2016 mgorse@suse.com
- Add fixes for some crashes, taken from upstream git (bsc#988745
  bsc#991450 CVE-2016-6352):
  gdk-pixbuf-bgo768688-bmp-overflow.patch
  gdk-pixbuf-bgo768484-ico-set-errors.patch
  gdk-pixbuf-bgo769738-bmp-overflow.patch
  gdk-pixbuf-bgo769170-ico-headers.patch
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstreamed patches: gdk-pixbuf-bgo758991.patch,
  0001-pixops-Don-t-overflow-variables-when-shifting-them.patch,
  gdk-pixbuf-bgo747605.patch, gdk-pixbuf-bgo752297.patch,
  0001-ico-Protect-against-overflow.patch,
  0001-pixops-use-gint64-in-more-places-to-avoid-overflow-w.patch,
  gdk-pixbuf-bsc960155-divide-by-zero.patch,
  gdk-pixbuf-bsc948790-tga-dos.patch and
  gdk-pixbuf-2-32-overflow-fixes.patch.
* Fri Mar 25 2016 zaitor@opensuse.org
- Update to version 2.34.0:
  + Don't force no static builds on Win32 (bgo#760369).
  + Updated translations.
* Mon Jan  4 2016 mgorse@suse.com
- Add gdk-pixbuf-bsc960155-divide-by-zero.patch -- fix a possible
  divide by zero (bsc#960155).
- Add gdk-pixbuf-2-32-overflow-fixes.patch,
  0001-ico-Protect-against-overflow.patch,
  gdk-pixbuf-bgo747605.patch, and gdk-pixbuf-bgo758991.patch:
  fix various overflows (bsc#958963 CVE-2015-7552).
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 2.33.2:
  + Fix two crashes in the bmp loader (bgo#747605, bgo#758991).
  + Updated translations.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 2.33.1:
  + Improve various tests.
  + ico: integer overflow fixes.
  + tga: rewrite the loader, introducing a buffer queue
    abstraction.
  + gif: fix thumbnailing animations.
  + Updated translations.
* Mon Dec 21 2015 mgorse@suse.com
- Update to version 2.32.3:
  + Fix two crashes in the bmp loader (bgo#747605, bgo#758991).
  + ico: integer overflow fixes.
  + Updated translations.
* Wed Nov 25 2015 mgorse@suse.com
- Add
  0001-pixops-use-gint64-in-more-places-to-avoid-overflow-w.patch:
  Fix some more overflows scaling a gif (bsc#948791 CVE-2015-7673).
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 2.32.2:
  + Avoid some integer overflow possibilities in scaling code.
  + Updated translations.
* Mon Oct  5 2015 mgorse@suse.com
- Add gdk-pixbuf-bsc948790-tga-dos.patch: fix an overflow and DoS
  with a TGA (bsc#948790 CVE-2015-7673).
- Add
  0001-pixops-Don-t-overflow-variables-when-shifting-them.patch: Fix
  overflow when scaling a gif (bsc#948791 CVE-2015-7674).
* Fri Sep 25 2015 zaitor@opensuse.org
- Update to version 2.32.1:
  + Make relocations optional.
  + Fix a crash due to overflow when scaling.
  + Drop loaders for some rare image formats: wbmp, ras, pcx.
  + Prevent testsuite failures due to lack of memory.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 2.32.0:
  + Fix build issues (bgo#754154).
  + Fix animation loading (bgo#755269).
  + More overflow fixes in the scaling code (bgo#754387).
  + Fix a crash in the tga loader.
  + Updated translations.
* Mon Sep 14 2015 mgorse@suse.com
- Add gdk-pixbuf-bgo752297.patch: Check for overflow before
  allocating memory when scaling (bsc#942801 CVE-2015-4491).
  Taken from upstream.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 2.31.7:
  + Fix several integer overflows (bgo#753908, bgo#753569).
  + Fix build failure with --disable-modules (bgo#740912).
  + Port animations to GTask.
  + Updated translations.
* Wed Aug 19 2015 zaitor@opensuse.org
- Update to version 2.31.6:
  + Really fix bgo#752297. This is CVE-2015-4491.
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 2.31.5:
  + Add support for g_autoptr for all object types (bgo#750497).
  + Avoid a possible divide-by-zero in the pixbuf loader
    (bgo#750440).
  + Remove gettext .pot file hack (bgo#743574).
  + Be more careful about integer overflow (bgo#752297).
  + Updated translations.
- Drop README from docs as it is now empty.
- Add generic www.gnome.org URL to silence a few lint warnings.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 2.31.4:
  + SVGZ icons in notification GNOME3 (bgo#648815).
  + gdk_pixbuf_apply_embedded_orientation is not working
    (bgo#725582).
  + Updated translations.
* Sun Mar  8 2015 zaitor@opensuse.org
- Update to version 2.31.3:
  + API changes: Revert an annotation change that broke bindings.
  + Build fixes:
  - Clean up configure
  - Fix Visual Studio build
  - Define MAP_ANONYMOUS when needed
  - Include gi18n-lib.h where needed
  + Updated translations.
* Sat Nov 22 2014 zaitor@opensuse.org
- Update to version 2.31.2:
  + API changes:
  - Deprecate GdkPixdata.
  - Add gdk_pixbuf_get_options() helper to list set options.
  - Annotations fixes for various functions.
  - Remove incorrect info about area-prepared signal.
  + Image format support changes:
  - Flag multi-page TIFF files.
  - Fix memory usage for GIF animations, add note about minimum
    frame length.
  - Return an error for truncated PNG files.
  - Add density (DPI) support for JPEG, PNG and TIFF.
  - Fix reading CMYK JPEG files generated by Photoshop.
  - Allow saving 1-bit mono TIFF files as used in faxes.
  - Simplify loader names.
  - Fix loading GIF files when the first write is short.
  - Add progressive loading to ICNS files.
  - Add support for 256x256 ICO files.
  - Fix reading MS AMCap2 BMP files.
  + Other:
  - Honour requested depth in Xlib.
  - Special-case compositing/copying with no scaling.
  - Add relocation support to OSX and Linux.
  - Prefer gdk-pixbuf's loaders to the GDI+ ones on Windows.
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 2.31.1:
  + Add gdk_pixbuf_get_file_info_async.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 2.31.0:
  + To improve the situation for language bindings, pixbufs can now
    be constructed from data in GBytes, and pixbuf data can also be
    extracted in this form. The GBytes data is treated as readonly,
    and gdk_pixbuf_get_pixels() will create a copy. To avoid this
    copy, a new function gdk_pixbuf_read_pixels() was introduced
    which returns a const pointer to the data without copying.
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 2.30.8:
  + Add missing nullability annotations.
  + Documentation improvements.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 2.30.7:
  + Documentation fixes.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 2.30.6:
  + Add annotations to gdk_pixbuf_save_to_buffer.
  + Win32 build fixes.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 2.30.5:
  + Convert documentation to markdown.
  + Updated translations.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 2.30.4:
  + Make test suite robust against disabled formats.
  + Fix test failure when using libpng without iTXt support.
  + Updated translations.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 2.30.3:
  + Expand the test suite.
  + Enable coverage testing with --enable-coverage.
  + Unify sniff buffer sizes across loaders: 4k everywhere.
  + Port to GTask (bgo#712704).
  + xpm: Fix scaling (bgo#686514).
  + xpm: Update colors from pango (bgo#678996).
  + qtif: fix fread() error check (bgo#721371).
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 2.30.2:
  + jpeg: fix icc profile loading and improve error handling.
  + Make --update-cache work better.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 2.30.1:
  + Only use RLIMIT_AS when available (bgo#708666).
  + Only use setrlimit when available (bgo#710690).
  + Avoid a bashism (bgo#711600).
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 2.30.0:
  + Visual C++ build fixes.
  + Updated translations.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.29.3:
  + Use GLib setup for installed tests.
  + Make installed tests find data files.
  + Updated translations.
* Sat Jun 22 2013 dimstar@opensuse.org
- Update to version 2.29.2:
  + Install some tests.
  + ANI: Set an error if we fail to produce an animation.
  + Updated translations.
* Sun May  5 2013 zaitor@opensuse.org
- Update to version 2.29.0:
  + Add gdk_pixbuf_loader_write_bytes (bgo#696917).
  + Update GIcon implementation (bgo#688820).
  + Fix libpng linking issues (bgo#698093).
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 2.28.1:
  + Fix build with libpng 1.6.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 2.27.3:
  + Allow prepare_func call in stop_load (bgo#695228).
  + Updated translations.
* Sun Mar  3 2013 zaitor@opensuse.org
- Update to version 2.27.2:
  + Make gdk_pixbuf_animation_new_from_file load png files
    (bgo#694148).
  + Fix string formatting for l10n extraction (bgo#693534).
  + Updated translations.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 2.27.1:
  + Allow loading animations from streams.
  + Allow loading animations from resources.
  + Fix cross-compiling for Windows and Wine (bgo#692072).
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 2.27.0:
  + The broken locking mechanism for loaders has been removed.
* Wed Nov 21 2012 dimstar@opensuse.org
- Do not provide typelib-1_0-GdkPixbuf-2_0-32bit (baselibs.conf):
  this only results in a big mess of duplicate provides. Adding
  ($HOSTTYPE) to the typelib() symbols does not work, as we'd
  otherwise no longer be able to use them against noarch packages.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 2.26.5:
  + Improve error message for missing cache file (bgo#686844).
  + Ensure we link to gobject (bgo#686822).
  + Silence custom make rule (bgo#686605).
  + Prevent an error pileup (bgo#686139).
  + Don't use AC_PATH_PROG (bgo#671516).
  + Updated translations.
- Drop gdk-pixbuf-link-gobject.patch: fixed upstream.
* Thu Oct 25 2012 dimstar@opensuse.org
- Add gdk-pixbuf-link-gobject.patch: Ensure to link against
  libgobject.
* Wed Oct 24 2012 jengelh@inai.de
- Make gdk-pixbuf-devel-32bit available on all archs
  (baselibs.conf).
* Tue Sep 18 2012 zaitor@opensuse.org
- Update to version 2.26.4:
  + Make tiff loader threadsafe.
  + Support saving ICC profiles in jpeg (bgo#604610).
  + Add some missing annotations (bgo#683064).
  + Documentation improvements (bgo#676430).
  + Updated translations.
- Clean up spec, remove source service checkout support.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 2.26.3:
  + Fix a minor string leak (bgo#681943)
  + Bail out as soon as a module is found (bgo#681943)
  + Add an option to disable GIO mime detection (bgo#676726)
  + Updated translations.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 2.26.2:
  + Various functions have been added to the docs
  + Fix introspection of gdk_pixbuf_new_from_xpm_data (bg0#668956)
  + Improve the gif loaders handling of animations with varying
    frame sizes (bgo#613595)
  + Updated translatons.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 2.26.1:
  + Fix srcdir != builddir build (bgo#672133)
  + Avoid an integer overflow in the xbm loader (bgo#672811)
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 2.26.0:
  + Correctly load .ANI files without sequence chunks.
  + Win32 build fixes.
  + Updated translations.
* Tue Feb  7 2012 vuntz@opensuse.org
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Sun Feb  5 2012 zaitor@opensuse.org
- Update to version 2.25.2:
  + New functions to load pixbufs from resources:
    gdk_pixbuf_new_from_resource,
    gdk_pixbuf_new_from_resource_at_scale.
  + gdk-pixbuf-pixdata is a new program that generates raw binary
    GdkPixdata files, and there is a new loader for these.
  + Updated translations.
- Drop gdk-pixbuf-missing-include.patch: fixed upstream.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 2.25.0:
  + Fix some string problems in the qtif loader (bgo#629396)
  + Fix various introspection annotations (bgo#659888)
  + Fix introspectability of gdk_pixbuf_get_pixels (bgo#662009)
  + Skip compressed icons in ICOs (bgo#652498)
  + Fix thread-safety issues with animations
  + Fix gif animation delays between frames (bgo#655755)
  + Work around gtk-doc limitations (bgo#663554)
  + Add a --with-x11 configure options (bgo#657569)
  + Fix build problem on NetBSD (bgo#640405)
  + Fix mingw build (bgo#657876)
  + Updated translations.
- Add gdk-pixbuf-missing-include.patch: add missing include.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Pass new --with-x11 option to configure.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file in typelib-1_0-GdkPixbuf-2_0 subpackage.
- Add typelib-1_0-GdkPixbuf-2_0 Requires to devel subpackage.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.24.0:
  + Clean up dependencies in the .pc file
  + Win32 build fixes
  + Updated translations.
* Tue Jun 28 2011 dimstar@opensuse.org
- Update to version 2.23.5:
  + Prevent the return of partically initialized pixbuf structures
    from the gif loader in some error cases (CVE-2011-2485)
  + Win32 build updates.
* Tue Jun 14 2011 vuntz@opensuse.org
- Update to version 2.23.4:
  + Drop use of G_CONST_RETURN
  + Win32 build fixes
  + Updated translations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.23.3:
  + Fix release tarball
  + More win32 build fixes
- Changes from version 2.23.2:
  + bgo#636138: Fix possible crashes when loading jpegs
  + Introspection annotation fixes
  + Update build files on Win32
  + Updated translations.
* Mon Mar  7 2011 fcrozat@novell.com
- Update to version 2.23.1:
  + Introspection:
  - Add package information
  - Don't include backend API
  + Fix build against libpng 1.5
  + Bugs fixed:
  - bgo#634659: gdk-pixbuf 2.22 can't find localisation
  - bgo#635364: Add C include and exported packages information
    to GIR
  - bgo#639922: Proposed Visual C++ 2008 Project Files
  - bgo#640407: Unportable test(1) construct in configure script.
  + Updated translations.
* Wed Feb 16 2011 fcrozat@novell.com
- Update to version 2.23.0:
  + New API: gdk_pixbuf_new_from_stream_async
  + Updated translations.
- Drop gdk-pixbuf-add-gir_PACKAGES.patch: fixed upstream. Also
  remove gnome-common BuildRequires and call to gnome-autogen.sh
  that were needed for the patch.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gtk-doc BuildRequires.
  + Add call to ./autogen.sh.
  + Enforce gtk-doc html generation by passing --enable-gtk-doc to
    configure.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Dec 28 2010 dimstar@opensuse.org
- Add gdk-pixbuf-add-gir_PACKAGES.patch: vapigen 0.12 parses the
  .gir and the .vapi file, complaining about duplicate definitions.
  The error is seen in packages building against gdk-pixbuf and
  using vala-unstable to create own vala bindings.
- Add gnome-common BuildRequires, because the patch touches
  Makefile.am, and call to gnome-autogen.sh in the build section.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 2.22.1:
  + Make GdkPixbuf implement the GIcon interface
  + Fix loader.cache detection on Windows
  + Updated translations.
* Wed Oct 13 2010 vuntz@opensuse.org
- Put comments that are in the scriptlets area of the spec file in
  "%%if 0" statement: if we don't do that, they actually end up in
  the scriplets and can even make them fail if the scriptlets were
  just "-p /sbin/ldconfig".
* Mon Oct 11 2010 vuntz@opensuse.org
- Remove gdk-pixbuf-query-loaders Requires(postun) in
  libgdk_pixbuf-2_0-0: it's not needed.
- Add missing Requires for gdk-pixbuf-query-loaders to
  libgdk_pixbuf-2_0-0 in baselibs.conf.
- Update baselibs.conf to remove assumption in the scriptlets of
  the generated packages that they are 32bit packages.
- Use <prefix> in baselibs.conf since we use full paths there, and
  this is needed for x86 packages that put files in
  /emul/ia32-linux.
* Tue Sep 21 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Fix a problem with mime type detection
  + Win32: Fix linking on x64
  + Drop gobject-introspection requirement to 0.9.3
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update the %%post scriptlet to not fail if
  gdk-pixbuf-query-loaders is not installed. Also make it easier to
  read by using a %%define to use the right binary for
  gdk-pixbuf-query-loaders.
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 2.21.7:
  + bgo#624712: Fix linking when libpng loader is builtin
  + bgo#604284: Improve the pixbuf loader docs
  + bgo#622940: Fix compat issues wrt to single includes
  + Win32: Link directly to GDI+
  + Require gobject-introspection 0.9.5
  + Updated translations.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 2.21.6:
  + Drop aliasing hacks, use -Bsymbolic-functions
  + Support NOCONFIGURE in autogen.sh
  + Check for different versions of libpng
* Wed Jul 21 2010 vuntz@opensuse.org
- Improve summaries and descriptions.
- Change gobject-introspection-devel and libpng-devel BuildRequires
  to pkgconfig(gobject-introspection-1.0) and pkgconfig(libpng).
- Add libjasper-devel, pkgconfig(x11) BuildRequires, and explicit
  libjpeg-devel.
- Add baselibs.conf, and rename gdk-pixbuf-query-loaders on 64
  bits.
- Make libgdk_pixbuf-2_0-0 provide gdk-pixbuf to make the lang
  package installable.
- Add Recommends for the lang package to libgdk_pixbuf-2_0-0.
- Move conflicts with gtk2 < 2.21 to libgdk_pixbuf-2_0-0.
- Stop renaming gdk-pixbuf-query-loaders to
  gdk-pixbuf-query-loaders-2.0: they're no issue with parallel
  instability since there's no other such tool.
- Touch %%{_libdir}/gdk-pixbuf-2.0/2.10.0/loaders.cache and make it
  a ghost file.
- Pass --disable-static and --with-libjasper to configure.
- Enable parallel build.
- Move gtk-doc documentation and gdk-pixbuf-csource to devel
  subpackage.
- Add a macros.gdk-pixbuf file containing useful macros for
  packages that ship gdk-pixbuf loaders.
* Tue Jul  6 2010 dimstar@opensuse.org
- Initial package of gdk-pixbuf, which has been split out of gtk2
  main package. For this reason it conflicts with gtk < 2.21
- Changes from version 2.21.5:
  + Bring back deprecated API
  + Allow including individual headers again
- Changes from version 2.21.4:
  + Drop -2.0 suffix on gdk-pixbuf-csource and
    gdk-pixbuf-query-loaders
  + Include gdk-pixbuf-xlib again
  + Add pixbuf tests from the GTK+ tree
  + Add binary version and module dir as variables in the .pc file
  + Add a boxed type for GdkPixbufFormat
- Changes from version 2.21.3, since GTK+ 2.21.2:
  + gdk-pixbuf has been turned back into a standalone library.
  + The default location for loaders has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders
  + The default location for the module file has been changed to
    $libdir/gdk-pixbuf-2.0/2.10.0/loaders.cache
    and gdk-pixbuf-query-loaders-2.0 will update that file when
    given the --update-cache option.
